@@ -262,6 +262,9 @@ def stan(file=None, model_name="anon_model", model_code=None, fit=None,
         - `adapt_delta` : float, between 0 and 1, default 0.8
         - `adapt_kappa` : float, between default 0.75
         - `adapt_t0`    : float, positive, default 10
+        - `adapt_init_buffer` : int, positive, defaults to 75
+        - `adapt_term_buffer` : int, positive, defaults to 50
+        - `adapt_window` : int, positive, defaults to 25
 
         In addition, the algorithm HMC (called 'static HMC' in Stan) and NUTS
         share the following parameters:
