@@ -26,6 +26,7 @@ import inspect
 import io
 import itertools
 import logging
+import math
 from numbers import Number
 import os
 import random
@@ -49,8 +50,7 @@ logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger('pystan')
 
 
-def _print_stanfit(fit, pars=None, probs=(0.025, 0.25, 0.5, 0.75, 0.975),
-                   digits_summary=1):
+def _print_stanfit(fit, pars=None, probs=(0.025, 0.25, 0.5, 0.75, 0.975), digits_summary=1):
         if fit.mode == 1:
             return "Stan model '{}' is of mode 'test_grad';\n"\
                    "sampling is not conducted.".format(fit.model_name)
@@ -97,7 +97,9 @@ def _array_to_table(arr, rownames, colnames, n_digits):
     """
     assert arr.shape == (len(rownames), len(colnames))
     rownames_maxwidth = max(len(n) for n in rownames)
-    widths = [rownames_maxwidth] + [max(5, len(n) + 1) for n in colnames]
+    max_col_width = 7
+    min_col_width = 5
+    widths = [rownames_maxwidth] + [max(max_col_width, max(len(n) + 1, min_col_width)) for n in colnames]
     header = '{:>{width}}'.format('', width=widths[0])
     for name, width in zip(colnames, widths[1:]):
         header += '{name:>{width}}'.format(name=name, width=width)
@@ -107,6 +109,10 @@ def _array_to_table(arr, rownames, colnames, n_digits):
         for j, (num, width) in enumerate(zip(row, widths[1:])):
             if colnames[j] == 'n_eff':
                 num = int(round(num, 0))
+            # FIXME: this is a hotfix just to avoid really ugly summaries.
+            # any number which has abs value more than 999 is turned into an int
+            if (math.floor(math.log10(abs(num))) + 1) > 3:
+                num = int(round(num))
             line += '{num:{width}}'.format(num=round(num, n_digits), width=width)
         lines.append(line)
     return '\n'.join(lines)
@@ -532,22 +538,24 @@ def _get_valid_stan_args(base_args=None):
             args['ctrl']['optim']['algorithm'] = optim_algo_t.BFGS
         elif algorithm == "Newton":
             args['ctrl']['optim']['algorithm'] = optim_algo_t.Newton
-        elif algorithm == "Nesterov":
-            args['ctrl']['optim']['algorithm'] = optim_algo_t.Nesterov
+        elif algorithm == "LBFGS":
+            args['ctrl']['optim']['algorithm'] = optim_algo_t.LBFGS
         else:
             msg = "Invalid value for parameter algorithm (found {}; " \
-                  "require BFGS, Newton, or Nesterov).".format(algorithm)
+                  "require (L)BFGS or Newton).".format(algorithm)
             raise ValueError(msg)
         refresh = args['ctrl']['optim']['iter'] // 100
         args['ctrl']['optim']['refresh'] = args.get('refresh', refresh)
         if args['ctrl']['optim']['refresh'] < 1:
             args['ctrl']['optim']['refresh'] = 1
-        args['ctrl']['optim']['stepsize'] = args.get("stepsize", 1.0)
         args['ctrl']['optim']['init_alpha'] = args.get("init_alpha", 0.001)
-        args['ctrl']['optim']['tol_obj'] = args.get("tol_obj", 1e-8)
+        args['ctrl']['optim']['tol_obj'] = args.get("tol_obj", 1e-12)
         args['ctrl']['optim']['tol_grad'] = args.get("tol_grad", 1e-8)
         args['ctrl']['optim']['tol_param'] = args.get("tol_param", 1e-8)
+        args['ctrl']['optim']['tol_rel_obj'] = args.get("tol_rel_obj", 1e4)
+        args['ctrl']['optim']['tol_rel_grad'] = args.get("tol_rel_grad", 1e7)
         args['ctrl']['optim']['save_iterations'] = args.get("save_iterations", True)
+        args['ctrl']['optim']['history_size'] = args.get("history_size", 5)
     elif args['method'] == stan_args_method_t.TEST_GRADIENT:
         args['ctrl'] = args.get('ctrl', dict(test_grad=dict()))
         args['ctrl']['test_grad']['epsilon'] = args.get("epsilon", 1e-6)
