@@ -9,6 +9,7 @@
 #include <stan/agrad/fwd/matrix/determinant.hpp>
 #include <stan/agrad/fwd/functions/fabs.hpp>
 #include <stan/agrad/fwd/functions/log.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
   namespace agrad {
@@ -17,7 +18,7 @@ namespace stan {
     inline 
     fvar<T>
     log_determinant(const Eigen::Matrix<fvar<T>, R, C>& m) {
-      stan::math::validate_square(m, "log_determinant");
+      stan::math::check_square("log_determinant(%1%)",m,"m",(double*)0);
 
       return stan::agrad::log(stan::agrad::fabs(stan::agrad::determinant(m)));
     }
