@@ -33,7 +33,6 @@
 #include <stan/model/util.hpp>
 
 #include <stan/optimization/newton.hpp>
-#include <stan/optimization/nesterov_gradient.hpp>
 #include <stan/optimization/bfgs.hpp>
 
 #include <stan/common/write_iteration_csv.hpp>
@@ -42,6 +41,7 @@
 #include <stan/common/write_model.hpp>
 #include <stan/common/write_error_msg.hpp>
 #include <stan/common/do_print.hpp>
+#include <stan/common/do_bfgs_optimize.hpp>
 #include <stan/common/print_progress.hpp>
 #include <stan/common/run_markov_chain.hpp>
 #include <stan/common/warmup.hpp>
@@ -394,45 +394,7 @@ namespace stan {
 
         double lp(0);
         int return_code = stan::gm::error_codes::CONFIG;
-        if (algo->value() == "nesterov") {
-          bool epsilon = dynamic_cast<stan::gm::real_argument*>(
-                         algo->arg("nesterov")->arg("stepsize"))->value();
-          
-          
-          stan::optimization::NesterovGradient<Model> ng(model, cont_vector, disc_vector,
-                                                         epsilon, &std::cout);
-          
-          lp = ng.logp();
-          
-          double lastlp = lp - 1;
-          std::cout << "Initial log joint probability = " << lp << std::endl;
-          if (output_stream && save_iterations) {
-            write_iteration(*output_stream, model, base_rng,
-                            lp, cont_vector, disc_vector);
-          }
-
-          int m = 0;
-          for (int i = 0; i < num_iterations; i++) {
-            lastlp = lp;
-            lp = ng.step();
-            ng.params_r(cont_vector);
-            if (do_print(i, refresh)) {
-              std::cout << "Iteration ";
-              std::cout << std::setw(2) << (m + 1) << ". ";
-              std::cout << "Log joint probability = " << std::setw(10) << lp;
-              std::cout << ". Improved by " << (lp - lastlp) << ".";
-              std::cout << std::endl;
-              std::cout.flush();
-            }
-            m++;
-            if (output_stream && save_iterations) {
-              write_iteration(*output_stream, model, base_rng,
-                              lp, cont_vector, disc_vector);
-            }
-
-          }
-          return_code = stan::gm::error_codes::OK;
-        } else if (algo->value() == "newton") {
+        if (algo->value() == "newton") {
           std::vector<double> gradient;
           try {
             lp = model.template log_prob<false, false>(cont_vector, disc_vector, &std::cout);
@@ -470,79 +432,51 @@ namespace stan {
           }
           return_code = stan::gm::error_codes::OK;
         } else if (algo->value() == "bfgs") {
-          
-          stan::optimization::BFGSLineSearch<Model> bfgs(model, cont_vector, disc_vector,
-                                                         &std::cout);
-          bfgs._opts.alpha0 = dynamic_cast<stan::gm::real_argument*>(
-                         algo->arg("bfgs")->arg("init_alpha"))->value();
-          bfgs._opts.tolF = dynamic_cast<stan::gm::real_argument*>(
-                         algo->arg("bfgs")->arg("tol_obj"))->value();
-          bfgs._opts.tolGrad = dynamic_cast<stan::gm::real_argument*>(
-                         algo->arg("bfgs")->arg("tol_grad"))->value();
-          bfgs._opts.tolX = dynamic_cast<stan::gm::real_argument*>(
-                         algo->arg("bfgs")->arg("tol_param"))->value();
-          bfgs._opts.maxIts = num_iterations;
-          
-          lp = bfgs.logp();
-          
-          std::cout << "initial log joint probability = " << lp << std::endl;
-          if (output_stream && save_iterations) {
-            write_iteration(*output_stream, model, base_rng,
-                            lp, cont_vector, disc_vector);
-          }
+          typedef stan::optimization::BFGSLineSearch<Model,stan::optimization::BFGSUpdate_HInv<> > Optimizer;
+          Optimizer bfgs(model, cont_vector, disc_vector, &std::cout);
 
-          int ret = 0;
+          bfgs._ls_opts.alpha0 = dynamic_cast<stan::gm::real_argument*>(
+                         algo->arg("bfgs")->arg("init_alpha"))->value();
+          bfgs._conv_opts.tolAbsF = dynamic_cast<stan::gm::real_argument*>(
+                         algo->arg("bfgs")->arg("tol_obj"))->value();
+          bfgs._conv_opts.tolRelF = dynamic_cast<stan::gm::real_argument*>(
+                         algo->arg("bfgs")->arg("tol_rel_obj"))->value();
+          bfgs._conv_opts.tolAbsGrad = dynamic_cast<stan::gm::real_argument*>(
+                         algo->arg("bfgs")->arg("tol_grad"))->value();
+          bfgs._conv_opts.tolRelGrad = dynamic_cast<stan::gm::real_argument*>(
+                         algo->arg("bfgs")->arg("tol_rel_grad"))->value();
+          bfgs._conv_opts.tolAbsX = dynamic_cast<stan::gm::real_argument*>(
+                         algo->arg("bfgs")->arg("tol_param"))->value();
+          bfgs._conv_opts.maxIts = num_iterations;
           
-          while (ret == 0) {  
-            if (do_print(bfgs.iter_num(), 50*refresh)) {
-              std::cout << "    Iter ";
-              std::cout << "     log prob ";
-              std::cout << "       ||dx|| ";
-              std::cout << "     ||grad|| ";
-              std::cout << "      alpha ";
-// MAB: commented out but left in because it may be useful for debugging in the future
-//              std::cout << "     alpha0 ";
-              std::cout << " # evals ";
-              std::cout << " Notes " << std::endl;
-            }
-            
-            ret = bfgs.step();
-            lp = bfgs.logp();
-            bfgs.params_r(cont_vector);
-            
-            if (do_print(bfgs.iter_num(), ret != 0 || !bfgs.note().empty(),refresh)) {
-              std::cout << " " << std::setw(7) << bfgs.iter_num() << " ";
-              std::cout << " " << std::setw(12) << std::setprecision(6) 
-                        << lp << " ";
-              std::cout << " " << std::setw(12) << std::setprecision(6) 
-                        << bfgs.prev_step_size() << " ";
-              std::cout << " " << std::setw(12) << std::setprecision(6) 
-                        << bfgs.curr_g().norm() << " ";
-              std::cout << " " << std::setw(10) << std::setprecision(4) 
-                        << bfgs.alpha() << " ";
-              // std::cout << " " << std::setw(10) << std::setprecision(4) 
-              // << bfgs.alpha0() << " ";
-              std::cout << " " << std::setw(7) 
-                        << bfgs.grad_evals() << " ";
-              std::cout << " " << bfgs.note() << " ";
-              std::cout << std::endl;
-            }
-            
-            if (output_stream && save_iterations) {
-              write_iteration(*output_stream, model, base_rng,
-                              lp, cont_vector, disc_vector);
-            }
-          }
-          
-          
-          if (ret >= 0) {
-            std::cout << "Optimization terminated normally: " << std::endl;
-            return_code = stan::gm::error_codes::OK;
-          } else {
-            std::cout << "Optimization terminated with error: " << std::endl;
-            return_code = stan::gm::error_codes::SOFTWARE;
-          }
-          std::cout << "  " << bfgs.get_code_string(ret) << std::endl;
+          return_code = do_bfgs_optimize(model,bfgs, base_rng,
+                                         lp, cont_vector, disc_vector,
+                                         output_stream, &std::cout, 
+                                         save_iterations, refresh);
+        } else if (algo->value() == "lbfgs") {
+          typedef stan::optimization::BFGSLineSearch<Model,stan::optimization::LBFGSUpdate<> > Optimizer;
+          Optimizer bfgs(model, cont_vector, disc_vector, &std::cout);
+
+          bfgs.get_qnupdate().set_history_size(dynamic_cast<gm::int_argument*>(
+                         algo->arg("lbfgs")->arg("history_size"))->value());
+          bfgs._ls_opts.alpha0 = dynamic_cast<gm::real_argument*>(
+                         algo->arg("lbfgs")->arg("init_alpha"))->value();
+          bfgs._conv_opts.tolAbsF = dynamic_cast<gm::real_argument*>(
+                         algo->arg("lbfgs")->arg("tol_obj"))->value();
+          bfgs._conv_opts.tolRelF = dynamic_cast<gm::real_argument*>(
+                         algo->arg("lbfgs")->arg("tol_rel_obj"))->value();
+          bfgs._conv_opts.tolAbsGrad = dynamic_cast<gm::real_argument*>(
+                         algo->arg("lbfgs")->arg("tol_grad"))->value();
+          bfgs._conv_opts.tolRelGrad = dynamic_cast<gm::real_argument*>(
+                         algo->arg("lbfgs")->arg("tol_rel_grad"))->value();
+          bfgs._conv_opts.tolAbsX = dynamic_cast<gm::real_argument*>(
+                         algo->arg("lbfgs")->arg("tol_param"))->value();
+          bfgs._conv_opts.maxIts = num_iterations;
+
+          return_code = do_bfgs_optimize(model,bfgs, base_rng,
+                                         lp, cont_vector, disc_vector,
+                                         output_stream, &std::cout, 
+                                         save_iterations, refresh);
         } else {
           return_code = stan::gm::error_codes::CONFIG;
         }
@@ -582,7 +516,7 @@ namespace stan {
         
         stan::common::recorder::csv sample_recorder(output_stream, "# ");
         stan::common::recorder::csv diagnostic_recorder(diagnostic_stream, "# ");
-        stan::common::recorder::messages message_recorder(output_stream, "# ");
+        stan::common::recorder::messages message_recorder(&std::cout, "# ");
         
         stan::io::mcmc_writer<Model, 
                               stan::common::recorder::csv, stan::common::recorder::csv,
@@ -617,12 +551,12 @@ namespace stan {
                                       parser.arg("method")->arg("sample")->arg("adapt"));
         bool adapt_engaged = dynamic_cast<stan::gm::bool_argument*>(adapt->arg("engaged"))->value();
         
-	if (model.num_params_r() == 0 && algo->value() != "fixed_param") {
-	  std::cout
-	    << "Must use algorithm=fixed_param for model that has no parameters."
-	    << std::endl;
-	  return -1;
-	}      
+        if (model.num_params_r() == 0 && algo->value() != "fixed_param") {
+          std::cout
+            << "Must use algorithm=fixed_param for model that has no parameters."
+            << std::endl;
+          return -1;
+        }      
 
         if (algo->value() == "fixed_param") {
           
