@@ -1,13 +1,15 @@
 #ifndef __STAN__GM__ARGUMENTS__TEST__GRADIENT__HPP__
 #define __STAN__GM__ARGUMENTS__TEST__GRADIENT__HPP__
 
-#include <stan/gm/arguments/unvalued_argument.hpp>
+#include <stan/gm/arguments/categorical_argument.hpp>
+#include <stan/gm/arguments/arg_test_grad_eps.hpp>
+#include <stan/gm/arguments/arg_test_grad_err.hpp>
 
 namespace stan {
   
   namespace gm {
     
-    class arg_test_gradient: public unvalued_argument {
+    class arg_test_gradient: public categorical_argument {
       
     public:
       
@@ -16,6 +18,9 @@ namespace stan {
         _name = "gradient";
         _description = "Check model gradient against finite differences";
         
+        _subarguments.push_back(new arg_test_grad_eps());
+        _subarguments.push_back(new arg_test_grad_err());
+        
       }
       
     };
