@@ -135,6 +135,11 @@ namespace stan {
       return et1.type() == DOUBLE_T ? et1 : et2;
     }
 
+    void function_signatures::reset_sigs() {
+      if (sigs_ == 0) return;
+      delete sigs_;
+      sigs_ = 0;
+    }
     function_signatures& function_signatures::instance() {
       // FIXME:  for threaded models, requires double-check lock
       if (!sigs_)
@@ -1086,6 +1091,16 @@ namespace stan {
         N_(N) {
     }
 
+    cholesky_corr_var_decl::cholesky_corr_var_decl() 
+      : base_var_decl(MATRIX_T) { 
+    }
+    cholesky_corr_var_decl::cholesky_corr_var_decl(expression const& K,
+                                                   std::string const& name,
+                                                   std::vector<expression> const& dims)
+      : base_var_decl(name,dims,MATRIX_T),
+        K_(K) {
+    }
+
     cov_matrix_var_decl::cov_matrix_var_decl() : base_var_decl(MATRIX_T) { 
     }
     cov_matrix_var_decl::cov_matrix_var_decl(expression const& K,
@@ -1140,6 +1155,9 @@ namespace stan {
     std::string name_vis::operator()(const cholesky_factor_var_decl& x) const {
       return x.name_;
     }
+    std::string name_vis::operator()(const cholesky_corr_var_decl& x) const {
+      return x.name_;
+    }
     std::string name_vis::operator()(const cov_matrix_var_decl& x) const {
       return x.name_;
     }
@@ -1163,6 +1181,7 @@ namespace stan {
     var_decl::var_decl(const ordered_var_decl& decl) : decl_(decl) { }
     var_decl::var_decl(const positive_ordered_var_decl& decl) : decl_(decl) { }
     var_decl::var_decl(const cholesky_factor_var_decl& decl) : decl_(decl) { }
+    var_decl::var_decl(const cholesky_corr_var_decl& decl) : decl_(decl) { }
     var_decl::var_decl(const cov_matrix_var_decl& decl) : decl_(decl) { }
     var_decl::var_decl(const corr_matrix_var_decl& decl) : decl_(decl) { }
 
