@@ -2,8 +2,8 @@
 #define __STAN__MATH__MATRIX__BLOCK_HPP__
 
 #include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/validate_row_index.hpp>
-#include <stan/math/matrix/validate_column_index.hpp>
+#include <stan/math/error_handling/matrix/check_row_index.hpp>
+#include <stan/math/error_handling/matrix/check_column_index.hpp>
 
 namespace stan {
   namespace math {
@@ -22,16 +22,12 @@ namespace stan {
     Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>
     block(const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& m,
           size_t i, size_t j, size_t nrows, size_t ncols) {
-      validate_row_index(m,i,"block");
-      validate_row_index(m,i+nrows-1,"block");
-      validate_column_index(m,j,"block");
-      validate_column_index(m,j+ncols-1,"block");
+      check_row_index("block(%1%)",i,m,"i",(double*)0);
+      check_row_index("block(%1%)",i+nrows-1,m,"i+nrows-1",(double*)0);
+      check_column_index("block(%1%)",j,m,"j",(double*)0);
+      check_column_index("block(%1%)",j+ncols-1,m,"j+ncols-1",(double*)0);
       return m.block(i - 1,j - 1,nrows,ncols);
     }
-
-
-
-    
     
   }
 }
