@@ -13,7 +13,7 @@ namespace stan {
       
     public:
       
-      stepsize_covar_adapter(int n, int max_adapt): _covar_adaptation(n, max_adapt)
+      stepsize_covar_adapter(int n): _covar_adaptation(n)
       {};
       
       stepsize_adaptation& get_stepsize_adaptation() {
@@ -24,6 +24,18 @@ namespace stan {
         return _covar_adaptation;
       }
       
+      void set_window_params(unsigned int num_warmup,
+                             unsigned int init_buffer,
+                             unsigned int term_buffer,
+                             unsigned int base_window,
+                             std::ostream* e = 0) {
+        _covar_adaptation.set_window_params(num_warmup,
+                                             init_buffer,
+                                             term_buffer,
+                                             base_window,
+                                             e);
+      }
+      
     protected:
       
       stepsize_adaptation _stepsize_adaptation;
