@@ -8,8 +8,10 @@
 #include <stan/prob/traits.hpp>
 #include <stan/math/error_handling.hpp>
 #include <stan/math/constants.hpp>
+#include <stan/math/functions/log1p.hpp>
 #include <stan/math/functions/square.hpp>
 #include <stan/math/functions/value_of.hpp>
+#include <stan/math/functions/log1p.hpp>
 #include <stan/prob/constants.hpp>
 
 namespace stan {
@@ -57,20 +59,15 @@ namespace stan {
       double logp(0.0);
 
       // validate args (here done over var, which should be OK)
-      if (!check_not_nan(function, y, "Random variable", &logp))
-        return logp;
-      if (!check_finite(function, mu, "Location parameter", &logp))
-        return logp;
-      if (!check_positive(function, sigma, "Scale parameter", &logp))
-        return logp;
-      if (!check_finite(function, sigma, "Scale parameter", &logp))
-        return logp;
-      if (!(check_consistent_sizes(function,
-                                   y,mu,sigma,
-                                   "Random variable","Location parameter",
-                                   "Scale parameter",
-                                   &logp)))
-        return logp;
+      check_not_nan(function, y, "Random variable", &logp);
+      check_finite(function, mu, "Location parameter", &logp);
+      check_positive(function, sigma, "Scale parameter", &logp);
+      check_finite(function, sigma, "Scale parameter", &logp);
+      check_consistent_sizes(function,
+                             y,mu,sigma,
+                             "Random variable","Location parameter",
+                             "Scale parameter",
+                             &logp);
 
       // check if no variables are involved and prop-to
       if (!include_summand<propto,T_y,T_loc,T_scale>::value)
@@ -177,19 +174,14 @@ namespace stan {
 
       double P(1.0);
         
-      if(!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if(!check_finite(function, mu, "Location parameter", &P))
-        return P;
-      if(!check_finite(function, sigma, "Scale parameter", &P))
-        return P;
-      if(!check_positive(function, sigma, "Scale parameter", &P))
-        return P;
-      if (!(check_consistent_sizes(function, y, mu, sigma,
-                                   "Random variable", "Location parameter", 
-                                   "Scale Parameter",
-                                   &P)))
-        return P;
+      check_not_nan(function, y, "Random variable", &P);
+      check_finite(function, mu, "Location parameter", &P);
+      check_finite(function, sigma, "Scale parameter", &P);
+      check_positive(function, sigma, "Scale parameter", &P);
+      check_consistent_sizes(function, y, mu, sigma,
+                             "Random variable", "Location parameter", 
+                             "Scale Parameter",
+                             &P);
         
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -280,18 +272,13 @@ namespace stan {
 
       double cdf_log(0.0);
         
-      if(!check_not_nan(function, y, "Random variable", &cdf_log))
-        return cdf_log;
-      if(!check_finite(function, mu, "Location parameter", &cdf_log))
-        return cdf_log;
-      if(!check_finite(function, sigma, "Scale parameter", &cdf_log))
-        return cdf_log;
-      if(!check_positive(function, sigma, "Scale parameter", &cdf_log))
-        return cdf_log;
-      if (!(check_consistent_sizes(function, y, mu, sigma,
-                                   "Random variable", "Location parameter", 
-                                   "Scale Parameter", &cdf_log)))
-        return cdf_log;
+      check_not_nan(function, y, "Random variable", &cdf_log);
+      check_finite(function, mu, "Location parameter", &cdf_log);
+      check_finite(function, sigma, "Scale parameter", &cdf_log);
+      check_positive(function, sigma, "Scale parameter", &cdf_log);
+      check_consistent_sizes(function, y, mu, sigma,
+                             "Random variable", "Location parameter", 
+                             "Scale Parameter", &cdf_log);
         
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -353,18 +340,13 @@ namespace stan {
 
       double ccdf_log(0.0);
         
-      if(!check_not_nan(function, y, "Random variable", &ccdf_log))
-        return ccdf_log;
-      if(!check_finite(function, mu, "Location parameter", &ccdf_log))
-        return ccdf_log;
-      if(!check_finite(function, sigma, "Scale parameter", &ccdf_log))
-        return ccdf_log;
-      if(!check_positive(function, sigma, "Scale parameter", &ccdf_log))
-        return ccdf_log;
-      if (!(check_consistent_sizes(function, y, mu, sigma,
-                                   "Random variable", "Location parameter", 
-                                   "Scale Parameter", &ccdf_log)))
-        return ccdf_log;
+      check_not_nan(function, y, "Random variable", &ccdf_log);
+      check_finite(function, mu, "Location parameter", &ccdf_log);
+      check_finite(function, sigma, "Scale parameter", &ccdf_log);
+      check_positive(function, sigma, "Scale parameter", &ccdf_log);
+      check_consistent_sizes(function, y, mu, sigma,
+                             "Random variable", "Location parameter", 
+                             "Scale Parameter", &ccdf_log);
         
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -418,12 +400,9 @@ namespace stan {
       using stan::math::check_positive;
       using stan::math::check_finite;
       
-      if (!check_finite(function, mu, "Location parameter"))
-        return 0;
-      if (!check_positive(function, sigma, "Scale parameter"))
-        return 0;
-      if (!check_finite(function, sigma, "Scale parameter"))
-        return 0;
+      check_finite(function, mu, "Location parameter", (double*)0);
+      check_positive(function, sigma, "Scale parameter", (double*)0);
+      check_finite(function, sigma, "Scale parameter", (double*)0);
 
       variate_generator<RNG&, cauchy_distribution<> >
         cauchy_rng(rng, cauchy_distribution<>(mu, sigma));
