@@ -55,17 +55,13 @@ namespace stan {
       using stan::math::check_consistent_sizes;
 
       double logp(0.0);
-      if (!check_finite(function, nu, "Degrees of freedom parameter", &logp))
-        return logp;
-      if (!check_positive(function, nu, "Degrees of freedom parameter", &logp))
-        return logp;
-      if (!check_not_nan(function, y, "Random variable", &logp))
-        return logp;
-      if (!(check_consistent_sizes(function,
-                                   y,nu,
-                                   "Random variable","Degrees of freedom parameter",
-                                   &logp)))
-        return logp;
+      check_finite(function, nu, "Degrees of freedom parameter", &logp);
+      check_positive(function, nu, "Degrees of freedom parameter", &logp);
+      check_not_nan(function, y, "Random variable", &logp);
+      check_consistent_sizes(function,
+                             y,nu,
+                             "Random variable","Degrees of freedom parameter",
+                             &logp);
 
        
       // set up template expressions wrapping scalars into vector views
@@ -157,19 +153,14 @@ namespace stan {
           
       double P(1.0);
           
-      if (!check_finite(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_positive(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_nonnegative(function, y, "Random variable", &P))
-        return P;
-      if (!(check_consistent_sizes(function, y, nu,
-                                   "Random variable", 
-                                   "Degrees of freedom parameter",
-                                   &P)))
-        return P;
+      check_finite(function, nu, "Degrees of freedom parameter", &P);
+      check_positive(function, nu, "Degrees of freedom parameter", &P);
+      check_not_nan(function, y, "Random variable", &P);
+      check_nonnegative(function, y, "Random variable", &P);
+      check_consistent_sizes(function, y, nu,
+                             "Random variable", 
+                             "Degrees of freedom parameter",
+                             &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -266,18 +257,13 @@ namespace stan {
           
       double P(0.0);
           
-      if (!check_finite(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_positive(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_nonnegative(function, y, "Random variable", &P))
-        return P;
-      if (!(check_consistent_sizes(function, y, nu,
-                                   "Random variable", 
-                                   "Degrees of freedom parameter", &P)))
-        return P;
+      check_finite(function, nu, "Degrees of freedom parameter", &P);
+      check_positive(function, nu, "Degrees of freedom parameter", &P);
+      check_not_nan(function, y, "Random variable", &P);
+      check_nonnegative(function, y, "Random variable", &P);
+      check_consistent_sizes(function, y, nu,
+                             "Random variable", 
+                             "Degrees of freedom parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -366,18 +352,13 @@ namespace stan {
           
       double P(0.0);
           
-      if (!check_finite(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_positive(function, nu, "Degrees of freedom parameter", &P))
-        return P;
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_nonnegative(function, y, "Random variable", &P))
-        return P;
-      if (!(check_consistent_sizes(function, y, nu,
-                                   "Random variable", 
-                                   "Degrees of freedom parameter", &P)))
-        return P;
+      check_finite(function, nu, "Degrees of freedom parameter", &P);
+      check_positive(function, nu, "Degrees of freedom parameter", &P);
+      check_not_nan(function, y, "Random variable", &P);
+      check_nonnegative(function, y, "Random variable", &P);
+      check_consistent_sizes(function, y, nu,
+                             "Random variable", 
+                             "Degrees of freedom parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -458,10 +439,8 @@ namespace stan {
       using stan::math::check_finite;      
       using stan::math::check_positive;
 
-      if (!check_finite(function, nu, "Degrees of freedom parameter"))
-        return 0;
-      if (!check_positive(function, nu, "Degrees of freedom parameter"))
-        return 0;
+      check_finite(function, nu, "Degrees of freedom parameter", (double*)0);
+      check_positive(function, nu, "Degrees of freedom parameter", (double*)0);
 
       variate_generator<RNG&, chi_squared_distribution<> >
         chi_square_rng(rng, chi_squared_distribution<>(nu));
