@@ -157,6 +157,7 @@ namespace stan {
       using stan::math::check_not_nan;
       using stan::math::value_of;
       using stan::math::check_consistent_sizes;
+      using stan::math::INV_SQRT_2;
 
       double cdf(1.0);
 
@@ -190,7 +191,15 @@ namespace stan {
         const double mu_dbl = value_of(mu_vec[n]);
         const double sigma_dbl = value_of(sigma_vec[n]);
         const double scaled_diff = (y_dbl - mu_dbl) / (sigma_dbl * SQRT_2);
-        const double cdf_ = 0.5 * (1.0 + erf(scaled_diff));
+        double cdf_;
+        if (scaled_diff < -37.5 * INV_SQRT_2)
+          cdf_ = 0.0;
+        else if (scaled_diff < -5.0 * INV_SQRT_2)
+          cdf_ = 0.5 * erfc(-scaled_diff);
+        else if (scaled_diff > 8.25 * INV_SQRT_2)
+          cdf_ = 1;
+        else
+          cdf_ = 0.5 * (1.0 + erf(scaled_diff));
 
         // cdf
         cdf *= cdf_;
@@ -229,6 +238,7 @@ namespace stan {
       using stan::math::check_not_nan;
       using stan::math::check_consistent_sizes;
       using stan::math::value_of;
+      using stan::math::INV_SQRT_2;
 
       double cdf_log(0.0);
       // check if any vectors are zero length
@@ -263,7 +273,16 @@ namespace stan {
 
         const double scaled_diff = (y_dbl - mu_dbl) / (sigma_dbl * SQRT_2);
         
-        const double one_p_erf = 1.0 + erf(scaled_diff);
+        double one_p_erf;
+        if (scaled_diff < -37.5 * INV_SQRT_2)
+          one_p_erf = 0.0;
+        else if (scaled_diff < -5.0 * INV_SQRT_2)
+          one_p_erf =  erfc(-scaled_diff);
+        else if (scaled_diff > 8.25 * INV_SQRT_2)
+          one_p_erf = 2.0;
+        else
+          one_p_erf = 1.0 + erf(scaled_diff);
+
         // log cdf
         cdf_log += log_half + log(one_p_erf);
 
@@ -291,6 +310,7 @@ namespace stan {
       using stan::math::check_not_nan;
       using stan::math::check_consistent_sizes;
       using stan::math::value_of;
+      using stan::math::INV_SQRT_2;
 
       double ccdf_log(0.0);
       // check if any vectors are zero length
@@ -325,7 +345,16 @@ namespace stan {
 
         const double scaled_diff = (y_dbl - mu_dbl) / (sigma_dbl * SQRT_2);
         
-        const double one_m_erf = 1.0 - erf(scaled_diff);
+        double one_m_erf;
+        if (scaled_diff < -37.5 * INV_SQRT_2)
+          one_m_erf = 2.0;
+        else if (scaled_diff < -5.0 * INV_SQRT_2)
+          one_m_erf =  2.0 - erfc(-scaled_diff);
+        else if (scaled_diff > 8.25 * INV_SQRT_2)
+          one_m_erf = 0.0;
+        else
+          one_m_erf = 1.0 - erf(scaled_diff);
+
         // log ccdf
         ccdf_log += log_half + log(one_m_erf);
 
