@@ -47,24 +47,16 @@ namespace stan {
         return 0.0;
       
       double logp(0.0);
-      if (!check_nonnegative(function, n, "Failures variable", &logp))
-        return logp;
-      if (!check_finite(function, alpha, "Shape parameter", &logp))
-        return logp;
-      if (!check_positive(function, alpha, "Shape parameter", &logp))
-        return logp;
-      if (!check_finite(function, beta, "Inverse scale parameter",
-                        &logp))
-        return logp;
-      if (!check_positive(function, beta, "Inverse scale parameter", 
-                          &logp))
-        return logp;
-      if (!(check_consistent_sizes(function,
-                                   n,alpha,beta,
-                                   "Failures variable",
-                                   "Shape parameter","Inverse scale parameter",
-                                   &logp)))
-        return logp;
+      check_nonnegative(function, n, "Failures variable", &logp);
+      check_finite(function, alpha, "Shape parameter", &logp);
+      check_positive(function, alpha, "Shape parameter", &logp);
+      check_finite(function, beta, "Inverse scale parameter", &logp);
+      check_positive(function, beta, "Inverse scale parameter", &logp);
+      check_consistent_sizes(function,
+                             n,alpha,beta,
+                             "Failures variable",
+                             "Shape parameter","Inverse scale parameter",
+                             &logp);
 
       // check if no variables are involved and prop-to
       if (!include_summand<propto,T_shape,T_inv_scale>::value)
@@ -206,27 +198,16 @@ namespace stan {
       double P(1.0);
           
       // Validate arguments
-      if (!check_finite(function, alpha, "Shape parameter", &P))
-        return P;
-          
-      if (!check_positive(function, alpha, "Shape parameter", &P))
-        return P;
-          
-      if (!check_finite(function, beta, "Inverse scale parameter",
-                        &P))
-        return P;
-          
-      if (!check_positive(function, beta, "Inverse scale parameter", 
-                          &P))
-        return P;
-          
-      if (!(check_consistent_sizes(function,
-                                   n, alpha, beta,
-                                   "Failures variable",
-                                   "Shape parameter",
-                                   "Inverse scale parameter",
-                                   &P)))
-        return P;
+      check_finite(function, alpha, "Shape parameter", &P);
+      check_positive(function, alpha, "Shape parameter", &P);
+      check_finite(function, beta, "Inverse scale parameter", &P);
+      check_positive(function, beta, "Inverse scale parameter", &P);
+      check_consistent_sizes(function,
+                             n, alpha, beta,
+                             "Failures variable",
+                             "Shape parameter",
+                             "Inverse scale parameter",
+                             &P);
           
       // Wrap arguments in vector views
       VectorView<const T_n> n_vec(n);
@@ -353,21 +334,16 @@ namespace stan {
       double P(0.0);
           
       // Validate arguments
-      if (!check_finite(function, alpha, "Shape parameter", &P))
-        return P;
-      if (!check_positive(function, alpha, "Shape parameter", &P))
-        return P;
-      if (!check_finite(function, beta, "Inverse scale parameter", &P))
-        return P;
-      if (!check_positive(function, beta, "Inverse scale parameter", &P))
-        return P;
-      if (!(check_consistent_sizes(function,
-                                   n, alpha, beta,
-                                   "Failures variable",
-                                   "Shape parameter",
-                                   "Inverse scale parameter",
-                                   &P)))
-        return P;
+      check_finite(function, alpha, "Shape parameter", &P);
+      check_positive(function, alpha, "Shape parameter", &P);
+      check_finite(function, beta, "Inverse scale parameter", &P);
+      check_positive(function, beta, "Inverse scale parameter", &P);
+      check_consistent_sizes(function,
+                             n, alpha, beta,
+                             "Failures variable",
+                             "Shape parameter",
+                             "Inverse scale parameter",
+                             &P);
           
       // Wrap arguments in vector views
       VectorView<const T_n> n_vec(n);
@@ -475,21 +451,16 @@ namespace stan {
       double P(0.0);
           
       // Validate arguments
-      if (!check_finite(function, alpha, "Shape parameter", &P))
-        return P;
-      if (!check_positive(function, alpha, "Shape parameter", &P))
-        return P;
-      if (!check_finite(function, beta, "Inverse scale parameter", &P))
-        return P;
-      if (!check_positive(function, beta, "Inverse scale parameter", &P))
-        return P;
-      if (!(check_consistent_sizes(function,
-                                   n, alpha, beta,
-                                   "Failures variable",
-                                   "Shape parameter",
-                                   "Inverse scale parameter",
-                                   &P)))
-        return P;
+      check_finite(function, alpha, "Shape parameter", &P);
+      check_positive(function, alpha, "Shape parameter", &P);
+      check_finite(function, beta, "Inverse scale parameter", &P);
+      check_positive(function, beta, "Inverse scale parameter", &P);
+      check_consistent_sizes(function,
+                             n, alpha, beta,
+                             "Failures variable",
+                             "Shape parameter",
+                             "Inverse scale parameter",
+                             &P);
           
       // Wrap arguments in vector views
       VectorView<const T_n> n_vec(n);
@@ -590,16 +561,12 @@ namespace stan {
       using stan::math::check_finite;      
       using stan::math::check_positive;
 
-      if (!check_finite(function, alpha, "Shape parameter"))
-        return 0;
-      if (!check_positive(function, alpha, "Shape parameter"))
-        return 0;
-      if (!check_finite(function, beta, "Inverse scale parameter"))
-        return 0;
-      if (!check_positive(function, beta, "Inverse scale parameter"))
-        return 0;
+      check_finite(function, alpha, "Shape parameter", (double*)0);
+      check_positive(function, alpha, "Shape parameter", (double*)0);
+      check_finite(function, beta, "Inverse scale parameter", (double*)0);
+      check_positive(function, beta, "Inverse scale parameter", (double*)0);
 
-      return stan::prob::poisson_rng(stan::prob::gamma_rng(alpha,1.0 / beta,
+      return stan::prob::poisson_rng(stan::prob::gamma_rng(alpha, beta,
                                                            rng),rng);
     }
   }
